cls

use "UVR-cataract-analysis.dta", clear	
save "UVR-cataract-analysis_7.dta", replace

local dateAn: di c(current_date)
cap log close
log using "`dateAn'_combinedUVR40+_6.smcl", replace

// Table 1: Demographic characteristics of study participants examined for the study 
// Age
bysort study_location: ci mean age
ci mean age
bysort study_location: tabstat age, stat(median min max)
tabstat age, stat(median min max)
// Gender
bysort study_location: tab gender
tab gender
// Education
bysort study_location: tab educat2
tab educat2
// Occupation (Present)
bysort study_location: tab workTypePrCat
tab workTypePrCat
// Lifetime cumulative effective sun exposure
bysort study_location: tabstat tExposure, stat(p50 min max)
tabstat tExposure, stat(p50 min max)

// Diabetes
bysort study_location: tab sugar200
tab sugar200 study_location, col chi

// Vision Status
bysort study_location: tab pvaBe
tab pvaBe study_location, col chi


// Table 2: Demographic details classified gender wise 
for var anyCataract cort_prev nuc_prev psc_prev: tab X study_location, col nokey


// Table 3: Prevalence of cataract in the presence of various risk factors
for var study_location agecat gender workTypePrCat ///
	educat2 smoke20 indoor16_kitchen tExposureQuantilesAll sugar200 pvaBe bvaBe: tab X anyCataract, row nokey chi


************************** CLINICAL ANY CATARACT
tab anyCataract
tab anyCataract study_location, col nokey chi
tab1 beOp  oneEyeOp 
tab1 beOp  oneEyeOp 

************* LOCS Assessment in eyes
tab excludeLocs
tab2 locsRe_cort locsLe_cort if anyCataract!=., mis
*** Type fo cataract
tab1 cort_locs_re cort_locs_le nuc_locs_re nuc_locs_le  psc_locs_re  psc_locs_le if anyCataract!=.
tab2 study_location cort_locs_re cort_locs_le nuc_locs_re nuc_locs_le  psc_locs_re  psc_locs_le if anyCataract!=. , firstonly row nokey chi
tab2 sugar200 		cort_locs_re cort_locs_le nuc_locs_re nuc_locs_le  psc_locs_re  psc_locs_le if anyCataract!=. , firstonly row nokey chi


*** Pattern in eyes
use "LOCSeyePattern.dta", clear
merge m:1 unique_id using  "UVR-cataract-analysis.dta", keepusing(sugar200)
keep if _merge==3
drop _merge

tab pattern
tab2 pattern study_location , col nokey chi
tab2 cort_locs eye 
tab2 nuc_locs eye 
tab2 psc_locs eye

tab2 cortAny eye, col
tab2 nucAny eye, col
tab2 pscAny eye, col
tab2 cortAny study_location, col
tab2 nucAny study_location, col
tab2 pscAny study_location, col

* Diabetes and type of opcacity
tab2 cortAny sugar200, col chi
tab2 nucAny sugar200, col  chi
tab2 pscAny sugar200, col  chi


* Gender wise
bysort gender: tab2 pattern study_location if pattern !=. & pattern !=1, mis nokey  chi
bysort gender: tab2 pattern study_location if pattern !=. & pattern !=1, mis col nokey nofreq chi
tab2 pattern gender if pattern !=. & pattern !=1, mis col nokey chi
bysort study_location: tab2 pattern gender if pattern !=. & pattern !=1,  col nokey chi


tab2 pattern sugar200 if pattern !=. & pattern !=1,  col nokey chi
logistic sugar200 i.pattern

* Vision in cataractous eyes
tab2 pva cortAny nucAny pscAny, firstonly nokey  chi  col
tab2 bva cortAny nucAny pscAny, firstonly nokey  chi  col
* pure
tab2 pattern  pva if pattern !=1 & pattern !=., firstonly nokey  chi row
tab2 pattern bva if pattern !=1 & pattern !=., firstonly nokey  chi  row

tab2 pattern bva if pattern !=. & pattern !=1, mis col nokey nofreq chi



** Prevalence of types of cataract in persons
use "UVR-cataract-analysis.dta", clear	
save "combinedUVR40+_7.dta", replace
local dateAn: di c(current_date)


tab1 cort_prev nuc_prev psc_prev if excludeLocs==0
tab2 study_location cort_prev nuc_prev psc_prev if excludeLocs==0 , firstonly row nokey chi

*** Distribution of pure cataracts
tab1 cort_assoc nuc_assoc psc_assoc pure_assoc
tab2 study_location  cort_assoc nuc_assoc psc_assoc pure_assoc , firstonly row nokey chi

*** Logistic Regtression Analysis
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==1, nolog
est sto loc1
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==2, nolog
est sto loc2
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==3, nolog
est sto loc3
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.study_location ///
		if educat2<5 , nolog	
est sto locAll

/*
// Logistic Regression Analysis *** With Pack Year Smokeing
logistic anyCataract ///
	gender i.educat2 smoke20 i.smokepackTotCat3 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==1 & smokepackTotCat3!=99 , nolog
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==2, nolog
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll ///
		if educat2<5 & study_location  ==3, nolog
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.study_location ///
		if educat2<5 , nolog	
*/


logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll  i.sugar200  ///
		if educat2<5 & study_location  ==1, nolog
est sto loc11
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.sugar200   ///
		if educat2<5 & study_location  ==2, nolog
est sto loc12
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.sugar200   ///
		if educat2<5 & study_location  ==3, nolog
est sto loc13
logistic anyCataract ///
	gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.study_location  i.sugar200  ///
		if educat2<5 , nolog	
est sto locAll_1

estout loc1 loc2 loc3 locAll, eform cells(b(star fmt(2)) p(fmt(3))) lab
di "With Diabetes"
estout loc11 loc12 loc13 locAll_1, eform cells(b( star  fmt(2)) p(fmt(3))) lab





*** Muninomial Lostic TRegression of pure cataracts
mlogit pure_assoc gender i.educat2 smoke20 indoor16_kitchen i.tExposureQuantilesAll i.study_location if educat2<5, allbaselevels  nolog

// 
// Gender ratio in all type of cataracts
for var anyCataract cort_prev nuc_prev psc_prev cort_assoc nuc_assoc psc_assoc pure_assoc: tab X gender, r col chi nokey
for var anyCataract cort_prev nuc_prev psc_prev cort_assoc nuc_assoc psc_assoc pure_assoc: bysort study_location: tab X gender, r col chi nokey

cap log close
view  "`dateAn'_combinedUVR40+_6.smcl"
translate "`dateAn'_combinedUVR40+_6.smcl" "results.pdf", replace

tab smokepackTotCat3 anyCataract
logistic anyCataract gender i.educat2 i.smokepackTotCat3 indoor16_kitchen i.tExposureQuantilesAll if educat2<5 & study_location==1 , nolog
logistic anyCataract gender i.educat2 i.smokepackTotCat3 indoor16_kitchen i.tExposureQuantilesAll if educat2<5 & study_location==2 , nolog
logistic anyCataract gender i.educat2 i.smokepackTotCat3 indoor16_kitchen i.tExposureQuantilesAll if educat2<5 & study_location==3 , nolog
logistic anyCataract gender i.educat2 i.smokepackTotCat3 indoor16_kitchen i.tExposureQuantilesAll if educat2<5  , nolog
